netapp_ontap.models.usm API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.usm`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class UsmSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Usm object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `authentication_password POST`

    Authentication protocol password.

    Example: humTdumt*@t0nAwa11

  `authentication_protocol GET POST PATCH`

    Authentication protocol.

    Valid choices:

    - none
    - md5
    - sha
    - sha2_256
  `links GET`

    The links field of the usm.

  `privacy_password POST`

    Privacy protocol password.

    Example: p@*GOandCLCt200

  `privacy_protocol GET POST PATCH`

    Privacy protocol.

    Valid choices:

    - none
    - des
    - aes128